# Validate AWS Policies Report

Access Analyzer Report for Permissions Set

filePolicy | summary
--- | ---
policy_allow_all_access_devs_special_users_2.json |
policyName | issueCode | findingType | details
--- | --- | --- | ---
policy_allow_all_access_devs_special_users_2 | CREATE_SLR_WITH_STAR_IN_ACTION_AND_RESOURCE | WARNING |
findingDetails | Using wildcards (*) in the action and the resource can allow creation of unintended service-linked roles because it allows iam:CreateServiceLinkedRole permissions on all resources. We recommend that you specify resource ARNs instead.
findingType | WARNING
issueCode | CREATE_SLR_WITH_STAR_IN_ACTION_AND_RESOURCE
learnMoreLink | https://docs.aws.amazon.com/IAM/latest/UserGuide/access-analyzer-reference-policy-checks.html#access-analyzer-reference-policy-checks-general-warning-create-slr-with-star-in-action-and-resource
locations |
path | span
--- | ---
- value | Statement
- index | 1
- value | Action
- index | 0
start |
line | 67
column | 8
offset | 1529
end |
line | 67
column | 11
offset | 1532
- value | Statement
- index | 1
- value | Resource
start |
line | 69
column | 18
offset | 1560
end |
line | 71
column | 7
offset | 1580
policy_allow_all_access_devs_special_users_2 | PASS_ROLE_WITH_STAR_IN_ACTION_AND_RESOURCE | SECURITY_WARNING |
findingDetails | Using wildcards (*) in the action and the resource can be overly permissive because it allows iam:PassRole permissions on all resources. We recommend that you specify resource ARNs or add the iam:PassedToService condition key to your statement.
findingType | SECURITY_WARNING
issueCode | PASS_ROLE_WITH_STAR_IN_ACTION_AND_RESOURCE
learnMoreLink | https://docs.aws.amazon.com/IAM/latest/UserGuide/access-analyzer-reference-policy-checks.html#access-analyzer-reference-policy-checks-security-warning-pass-role-with-star-in-action-and-resource
locations |
path | span
--- | ---
- value | Statement
- index | 1
- value | Action
- index | 0
start |
line | 67
column | 8
offset | 1529
end |
line | 67
column | 11
offset | 1532
- value | Statement
- index | 1
- value | Resource
- index | 0
start |
line | 70
column | 7
offset | 1569
end |
line | 70
column | 10
offset | 1572
policy_allow_all_access_devs_special_users.json |
policyName | issueCode | findingType | details
--- | --- | --- | ---
policy_allow_all_access_devs_special_users | None | None | No findings